<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de" sourcelanguage="en">
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Programmsprache auswählen</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Betriebssystemsprache&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Achtung!</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Programm neu starten, um die Sprachänderung wirksam werden zu lassen.</translation>
    </message>
</context>
<context>
    <name>Report</name>
    <message>
        <source>Time Sheet Report</source>
        <translation>Zeiterfassungsbericht</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Company:</source>
        <translation>Firma:</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Anschrift:</translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Tel.:</translation>
    </message>
    <message>
        <source>Fax:</source>
        <translation>Fax:</translation>
    </message>
    <message>
        <source>Email:</source>
        <translation>E-Mail:</translation>
    </message>
    <message>
        <source>Website:</source>
        <translation>Website:</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Prepend currency symbol</source>
        <translation>Währungssymbol voranstellen</translation>
    </message>
    <message>
        <source>Hourly rate:</source>
        <translation>Stundensatz:</translation>
    </message>
    <message>
        <source>Tax rate:</source>
        <translation>MwSt.-Satz:</translation>
    </message>
    <message>
        <source>Currency symbol:</source>
        <translation>Währungssymbol:</translation>
    </message>
    <message>
        <source>Contact Information</source>
        <translation>Kontaktdaten</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Zeiterfassungsdaten</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Web Page (*.html *.htm)</source>
        <translation>Web Page (*.html *.htm)</translation>
    </message>
    <message>
        <source>iCalendar (*.ics)</source>
        <translation>iCalendar (*.ics)</translation>
    </message>
    <message>
        <source>Outlook CSV (*.csv)</source>
        <translation>Outlook CSV (*.csv)</translation>
    </message>
    <message>
        <source>Export Report</source>
        <translation>Bericht exportieren</translation>
    </message>
    <message>
        <source>View Reports</source>
        <translation>Berichte anzeigen</translation>
    </message>
    <message>
        <source>Create Report</source>
        <translation>Bericht erstellen</translation>
    </message>
    <message>
        <source>Phone: %1</source>
        <translation>Tel.: %1</translation>
    </message>
    <message>
        <source>Fax: %1</source>
        <translation>Fax: %1</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Stunden</translation>
    </message>
    <message>
        <source>Subtotal</source>
        <translation>Zwischensumme</translation>
    </message>
    <message>
        <source>Taxes</source>
        <translation>MwSt.</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Endsumme</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n Stunde</numerusform>
            <numerusform>%n Stunden</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 hours</source>
        <translation>%L1 Stunden</translation>
    </message>
</context>
<context>
    <name>SessionDelegate</name>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation>Überschneidung mit anderem Eintrag.</translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <source>Add Session</source>
        <translation>Eintrag hinzufügen</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Start:</translation>
    </message>
    <message>
        <source>Stop:</source>
        <translation>Ende:</translation>
    </message>
    <message>
        <source>Task:</source>
        <translation>Aufgabe:</translation>
    </message>
    <message>
        <source>Edit Session</source>
        <translation>Eintrag bearbeiten</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>Total</source>
        <translation>Summe</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Ende</translation>
    </message>
    <message>
        <source>Task</source>
        <translation>Aufgabe</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Stunden</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Täglich</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Wöchentlich</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Monatlich</translation>
    </message>
    <message>
        <source>Report</source>
        <translation>Bericht</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>00:00:00</source>
        <translation>00:00:00</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimieren</translation>
    </message>
    <message>
        <source>&amp;Project</source>
        <translation>&amp;Projekt</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Hinzufügen</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Strg+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Entfernen</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <translation>Strg+Shift+Entf</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Eintrag</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>Ctrl+Delete</source>
        <translation>Strg+Entf</translation>
    </message>
    <message>
        <source>S&amp;ettings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>Columns</source>
        <translation>Spalten</translation>
    </message>
    <message>
        <source>&amp;Decimal Totals</source>
        <translation>&amp;Zeitanzeige dezimal</translation>
    </message>
    <message>
        <source>&amp;Inline Editing</source>
        <translation>&amp;direkte Wertebearbeitung</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programmsprache</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>Project</source>
        <translation>Projekt</translation>
    </message>
    <message>
        <source>Timer</source>
        <translation>Zeiterfassung</translation>
    </message>
    <message>
        <source>Show all</source>
        <translation>Alle anzeigen</translation>
    </message>
    <message>
        <source>Show only unbilled</source>
        <translation>Nur nicht abgerechnete anzeigen</translation>
    </message>
    <message>
        <source>Show only this year</source>
        <translation>Nur dieses Jahr anzeigen</translation>
    </message>
    <message>
        <source>Show only this month</source>
        <translation>Nur diesen Monat anzeigen</translation>
    </message>
    <message>
        <source>Show only this week</source>
        <translation>Nur diese Woche anzeigen</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-2011 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Veröffentlicht unter &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Session conflicts with other sessions.</source>
        <translation>Überschneidung mit anderem Eintrag.</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Wiederherstellen</translation>
    </message>
    <message>
        <source>Unable to read time data.</source>
        <translation>Unfähig die Zeit zu lesen.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Ohne Titel</translation>
    </message>
    <message>
        <source>Unable to write time data.</source>
        <translation>Unfähig die Zeit Daten zu schreiben. </translation>
    </message>
    <message>
        <source>There are timers running. Stop timers and quit?</source>
        <translation>Zeiterfassung läuft. Stoppen und Programm beenden?</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>A program to help track spent time</source>
        <translation>Ein Programm zur Zeiterfassung am Rechner.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>&amp;Create Report...</source>
        <translation>Bericht erstellen...</translation>
    </message>
    <message>
        <source>View R&amp;eports</source>
        <translation>Berichte anzeigen</translation>
    </message>
    <message>
        <source>Cancel this session?</source>
        <translation>Eintrag abbrechen?</translation>
    </message>
    <message>
        <source>Add Project</source>
        <translation>Projekt hinzufügen</translation>
    </message>
    <message>
        <source>Enter project name:</source>
        <translation>Projektname eingeben:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Unable to create time data location.</source>
        <translation>Der Zeitdaten Standort kann nicht erstellt werden.</translation>
    </message>
    <message>
        <source>Unable to move time data location.</source>
        <translation>Der Zeitdaten Speicherort kann nicht verschoben werden.</translation>
    </message>
    <message>
        <source>A project with that name already exists.</source>
        <translation>Ein Projekt dieses Namens besteht bereits.</translation>
    </message>
    <message>
        <source>Remove selected project?</source>
        <translation>Ausgewähltes Projekt löschen?</translation>
    </message>
    <message>
        <source>Remove selected session?</source>
        <translation>Ausgewählten Eintrag löschen?</translation>
    </message>
    <message numerus="yes">
        <source>%n timer(s) running</source>
        <translation>
            <numerusform>%n Zeiterfassung läuft</numerusform>
            <numerusform>%n Zeiterfassungen laufen</numerusform>
        </translation>
    </message>
    <message>
        <source>Kapow Punch Clock</source>
        <translation>Kapow Zeiterfassung</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Punch clock program</source>
        <translation>Zeiterfassungsprogramm</translation>
    </message>
    <message>
        <source>Store settings as INI format in specified file.</source>
        <translation>Die Einstellungen als INI-Format in der angegebenen Datei speichern.</translation>
    </message>
    <message>
        <source>file</source>
        <translation>Datei</translation>
    </message>
    <message>
        <source>Do not create automatic backups of time data.</source>
        <translation>Keine automatischen Backups von Zeitdaten erstellen.</translation>
    </message>
    <message>
        <source>The time data file to use.</source>
        <translation>Die verwendete Zeitdatendatei.</translation>
    </message>
</context>
</TS>
